==> jc-1.4.0.tar.gz: java/util/ResourceBundle__24BundleKey.h <==
// class java.util.ResourceBundle$BundleKey

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e014502f85c94075 java_util_ResourceBundle__24BundleKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_ResourceBundle__24BundleKey_H_
#define _JC_java_util_ResourceBundle__24BundleKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_java_util_ResourceBundle__24BundleKey$sub_refs	_jc_java_util_ResourceBundle__24BundleKey$sub_refs;
typedef struct _jc_java_util_ResourceBundle__24BundleKey$sub_nonrefs	_jc_java_util_ResourceBundle__24BundleKey$sub_nonrefs;
typedef struct _jc_java_util_ResourceBundle__24BundleKey$refs	_jc_java_util_ResourceBundle__24BundleKey$refs;
typedef struct _jc_java_util_ResourceBundle__24BundleKey$nonrefs	_jc_java_util_ResourceBundle__24BundleKey$nonrefs;
typedef struct _jc_java_util_ResourceBundle__24BundleKey$object	_jc_java_util_ResourceBundle__24BundleKey$object;

typedef const struct _jc_java_util_ResourceBundle__24BundleKey$vmethods	_jc_java_util_ResourceBundle__24BundleKey$vmethods;
typedef const struct _jc_java_util_ResourceBundle__24BundleKey$vtable	_jc_java_util_ResourceBundle__24BundleKey$vtable;
typedef const struct _jc_java_util_ResourceBundle__24BundleKey$vtype	_jc_java_util_ResourceBundle__24BundleKey$vtype;

// Constructors
extern void _jc_java_util_ResourceBundle__24BundleKey$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *);
extern void _jc_java_util_ResourceBundle__24BundleKey$method$_init$dcc9c939cf72e167(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual methods
extern jboolean _jc_java_util_ResourceBundle__24BundleKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_java_util_ResourceBundle__24BundleKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *);
extern void _jc_java_util_ResourceBundle__24BundleKey$method$set$27bd6f3259a71bd9(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *, struct _jc_java_lang_ClassLoader$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_ResourceBundle__24BundleKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_ResourceBundle__24BundleKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_ResourceBundle__24BundleKey$method_info$set$27bd6f3259a71bd9;

// Virtual methods structure
struct _jc_java_util_ResourceBundle__24BundleKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *);
	void	(*set$27bd6f3259a71bd9)(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *, struct _jc_java_lang_ClassLoader$object *);
};

// Vtable
struct _jc_java_util_ResourceBundle__24BundleKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle__24BundleKey$vmethods	java_util_ResourceBundle__24BundleKey;
};

// Vtype
struct _jc_java_util_ResourceBundle__24BundleKey$vtype {
	_jc_type			type;
	_jc_java_util_ResourceBundle__24BundleKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_ResourceBundle__24BundleKey$sub_refs {
	struct _jc_java_lang_String$object	*baseName;
	struct _jc_java_util_Locale$object	*locale;
	struct _jc_java_lang_ClassLoader$object	*classLoader;
};

// Reference instance fields (object)
struct _jc_java_util_ResourceBundle__24BundleKey$refs {
    _jc_java_util_ResourceBundle__24BundleKey$sub_refs	java_util_ResourceBundle__24BundleKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_ResourceBundle__24BundleKey$sub_nonrefs {
	jint	hashcode;
};

// Non-reference instance fields (object)
struct _jc_java_util_ResourceBundle__24BundleKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle__24BundleKey$sub_nonrefs	java_util_ResourceBundle__24BundleKey;
};

// Object instance structure
struct _jc_java_util_ResourceBundle__24BundleKey$object {
	_jc_java_util_ResourceBundle__24BundleKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_ResourceBundle__24BundleKey$vtype	*vtype;
	_jc_java_util_ResourceBundle__24BundleKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_ResourceBundle__24BundleKey$vtype _jc_java_util_ResourceBundle__24BundleKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_ResourceBundle__24BundleKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_ResourceBundle__24BundleKey$class_object;

#endif	/* _JC_java_util_ResourceBundle__24BundleKey_H_ */

==> jc-1.4.6.tar.gz: java/util/ResourceBundle__24BundleKey.h <==
// class java.util.ResourceBundle$BundleKey

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e014502f85c94075 java_util_ResourceBundle__24BundleKey

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_util_ResourceBundle__24BundleKey_H_
#define _JC_java_util_ResourceBundle__24BundleKey_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_ClassLoader$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;

// Typedefs
typedef struct _jc_java_util_ResourceBundle__24BundleKey$sub_refs	_jc_java_util_ResourceBundle__24BundleKey$sub_refs;
typedef struct _jc_java_util_ResourceBundle__24BundleKey$sub_nonrefs	_jc_java_util_ResourceBundle__24BundleKey$sub_nonrefs;
typedef struct _jc_java_util_ResourceBundle__24BundleKey$refs	_jc_java_util_ResourceBundle__24BundleKey$refs;
typedef struct _jc_java_util_ResourceBundle__24BundleKey$nonrefs	_jc_java_util_ResourceBundle__24BundleKey$nonrefs;
typedef struct _jc_java_util_ResourceBundle__24BundleKey$object	_jc_java_util_ResourceBundle__24BundleKey$object;

typedef const struct _jc_java_util_ResourceBundle__24BundleKey$vmethods	_jc_java_util_ResourceBundle__24BundleKey$vmethods;
typedef const struct _jc_java_util_ResourceBundle__24BundleKey$vtable	_jc_java_util_ResourceBundle__24BundleKey$vtable;
typedef const struct _jc_java_util_ResourceBundle__24BundleKey$vtype	_jc_java_util_ResourceBundle__24BundleKey$vtype;

// Constructors
extern void _jc_java_util_ResourceBundle__24BundleKey$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_ResourceBundle__24BundleKey$method$_init$dcc9c939cf72e167(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_java_util_ResourceBundle__24BundleKey$method$equals$8a15e0625571c581(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_java_util_ResourceBundle__24BundleKey$method$hashCode$53152098849316df(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *) _JC_JCNI_ATTR;
extern void _jc_java_util_ResourceBundle__24BundleKey$method$set$27bd6f3259a71bd9(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_ResourceBundle__24BundleKey$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_java_util_ResourceBundle__24BundleKey$method_info$hashCode$53152098849316df;
extern _jc_method _jc_java_util_ResourceBundle__24BundleKey$method_info$set$27bd6f3259a71bd9;

// Virtual methods structure
struct _jc_java_util_ResourceBundle__24BundleKey$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *) _JC_JCNI_ATTR;
	void	(*set$27bd6f3259a71bd9)(_jc_env *, struct _jc_java_util_ResourceBundle__24BundleKey$object *, struct _jc_java_lang_String$object *, struct _jc_java_util_Locale$object *, struct _jc_java_lang_ClassLoader$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_ResourceBundle__24BundleKey$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle__24BundleKey$vmethods	java_util_ResourceBundle__24BundleKey;
};

// Vtype
struct _jc_java_util_ResourceBundle__24BundleKey$vtype {
	_jc_type			type;
	_jc_java_util_ResourceBundle__24BundleKey$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_ResourceBundle__24BundleKey$sub_refs {
	struct _jc_java_lang_String$object	*baseName;
	struct _jc_java_util_Locale$object	*locale;
	struct _jc_java_lang_ClassLoader$object	*classLoader;
};

// Reference instance fields (object)
struct _jc_java_util_ResourceBundle__24BundleKey$refs {
    _jc_java_util_ResourceBundle__24BundleKey$sub_refs	java_util_ResourceBundle__24BundleKey;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_ResourceBundle__24BundleKey$sub_nonrefs {
	jint	hashcode;
};

// Non-reference instance fields (object)
struct _jc_java_util_ResourceBundle__24BundleKey$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle__24BundleKey$sub_nonrefs	java_util_ResourceBundle__24BundleKey;
};

// Object instance structure
struct _jc_java_util_ResourceBundle__24BundleKey$object {
	_jc_java_util_ResourceBundle__24BundleKey$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_ResourceBundle__24BundleKey$vtype	*vtype;
	_jc_java_util_ResourceBundle__24BundleKey$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_ResourceBundle__24BundleKey$vtype _jc_java_util_ResourceBundle__24BundleKey$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_ResourceBundle__24BundleKey, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_ResourceBundle__24BundleKey$class_object;

#endif	/* _JC_java_util_ResourceBundle__24BundleKey_H_ */
